@@ -11,6 +11,7 @@ from django.contrib.auth.models import User
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.contenttypes import generic
 from django.template.defaultfilters import slugify
+from django.conf import settings as conf
 
 class Pages(models.Model):
 
@@ -27,6 +28,8 @@ class Pages(models.Model):
     ip = models.CharField(_('IP'), max_length=100)
     hits = models.IntegerField(_('Hits'))
     status =  models.BooleanField(_('Status'), default=True)
+    template = models.CharField(_('Render template'), max_length=100,
+        choices=conf.RFLAT_TEMPLATES, blank=True)
 
     def __unicode__(self):
         return self.slug
